@@ -1,10 +1,10 @@
 package NOLookup;
-
 use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "1.38.0";
+our $VERSION = "1.01";
+
 
 =pod 
 
@@ -20,20 +20,20 @@ See the POD for the respective lookup modules.
 
 =head1 DESCRIPTION
 
-Search and lookup information about Norwegian domains, organizations and trademarks.
+Search and lookup information about Noriwegian domains, organizations and trademarks.
 
 See POD for each lookup module for further details.
 
 =head1 LICENSE
 
-Copyright (C) 2017- Trond Haugen.
+Copyright (C) 2017 Trond Haugen.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-Trond Haugen, E<lt>(nospam)info(at)norid.noE<gt>
+Trond Haugen E<lt>trondh@uninett.noE<gt>
 
 =cut
 
