@@ -1,6 +1,5 @@
 package NOLookup::Brreg::Entry;
 
-use warnings;
 use strict;
 use base qw(Class::Accessor::Chained); ## provides a new() method
 use Encode;
@@ -9,6 +8,8 @@ use POSIX qw(locale_h);
 use Data::Dumper;
 $Data::Dumper::Indent=1;
 
+our $VERSION = 1.01;
+
 # module methods
 my @module_methods = (
 
@@ -18,26 +19,19 @@ my @module_methods = (
        warning
 
        map_json_entries
-
        next_page
-       cur_page
-       prev_page
-       total_page_count
-
-       result_count
-       total_result_count
 
     /);
 
-
-# Brreg entry name
+# note: orgnr is inserted to be compatible with
+# Difi entry name
 my @json_data_methods = ( 
     
     # number and name
     qw /
        organisasjonsnummer
+       orgnr
        navn
-       oppdateringsid
     /,
     
     # dates
@@ -45,23 +39,21 @@ my @json_data_methods = (
        registreringsdatoEnhetsregisteret
        stiftelsesdato
        sisteInnsendteAarsregnskap
-       slettedato
-       oppstartsdato
-       dato
-       datoEierskifte
     /,
 
+    # Org form, like AS etc.
     qw /
+       organisasjonsform
        overordnetEnhet
-       maalform
     /,
 
-    # BOOL
+    # BOOL (J/N)
     qw /
        registrertIStiftelsesregisteret
        registrertIFrivillighetsregisteret
        registrertIMvaregisteret
        registrertIForetaksregisteret
+       frivilligRegistrertIMvaregisteret
        underAvvikling
        konkurs
        underTvangsavviklingEllerTvangsopplosning
@@ -70,28 +62,19 @@ my @json_data_methods = (
     # hashes with their own extra keys
     qw /
        forretningsadresse
-       beliggenhetsadresse
        postadresse
        institusjonellSektorkode
        naeringskode1
        naeringskode2
        naeringskode3
-       _links
-       page
-       organisasjonsform
+       links
     /,
 
     # web page, number of employed
     qw /
        hjemmeside
        antallAnsatte
-    /,
-
-    # Arrays
-    qw / 
-       frivilligMvaRegistrertBeskrivelser
-    /
-    
+    / 
     );
 
 # The new method and also the accessor methods
@@ -104,79 +87,47 @@ sub map_json_entries {
     my ($self, $json) = @_;
 
     return unless ($json);    
-        
+	
     my @aj;
     my @ao;
 
     $self->status("");
     if ($json->{navn}) {
-        # single entry on the data array
-        push @aj, $json;
-
-    } elsif ($json->{_embedded} && $json->{_embedded}->{enheter}) {
-        # multiple entries
-        push @aj, @{$json->{_embedded}->{enheter}};
-
-    } elsif ($json->{_embedded} && $json->{_embedded}->{underenheter}) {
-        # multiple entries
-        push @aj, @{$json->{_embedded}->{underenheter}};
-
-    } elsif ($json->{_embedded} && $json->{_embedded}->{oppdaterteEnheter}) {
-        # multiple updated entries
-        push @aj, @{$json->{_embedded}->{oppdaterteEnheter}};
-
-    } elsif ($json->{_embedded} && $json->{_embedded}->{oppdaterteUnderenheter}) {
-        # multiple updated entries
-        push @aj, @{$json->{_embedded}->{oppdaterteUnderenheter}};
-
+	# single entry on the data array
+	push @aj, $json;
+	
+    } elsif ($json->{data}) {
+	# multiple entries 
+	push @aj, @{$json->{data}};
     }
-
-    # count the current posts
-    $self->result_count(scalar  @aj);
     
-    #print STDERR "Entry self: ", Dumper $self;
-
-    if ($json->{page}) {
-        # page data
-        #print STDERR "page entry: ", Dumper $json->{page};
-
-	$self->total_result_count($json->{page}->{totalElements});
-	$self->cur_page($json->{page}->{number});
-	$self->total_page_count($json->{page}->{totalPages});
-	    
-	$self->prev_page(undef);
-	$self->next_page(undef);
-
-	if ($self->cur_page > 0) {
-	    $self->prev_page($self->cur_page - 1);
-	}
-	if ($self->total_page_count > $self->cur_page) {
-	    $self->next_page($self->cur_page + 1);
-	}
-    }
-
-    # Mape found orgs into NOLookup::Brreg::Entry objects
+    # Check entry array for supported keys
+    # set a warning if some are not expected
     foreach my $ej (@aj) {
-        foreach my $k (keys %$ej) {
-	    # Check entry array for supported keys
-	    # set a warning if some are not expected
-            unless ($self->can($k)) {
-                $self->status($self->status . "JSON data key entry not expected: $k\n");
-                $self->warning(1);
-            }
-        }
-        my $eo = NOLookup::Brreg::Entry->new($ej);
-        push @ao, $eo;
+	foreach my $k (keys %$ej) {
+	    unless ($self->can($k)) {
+		$self->status($self->status . "JSON data key entry not expected: $k\n");
+		$self->warning(1);
+	    }
+	}
+	my $eo = NOLookup::Brreg::Entry->new($ej);
+	$eo->orgnr($eo->organisasjonsnummer);  
+	push @ao, $eo;
     }
-
+    # Set next link page if more pages are present 
+    $self->next_page(undef);
+    foreach my $l (@{$json->{links}}) {
+	if ($l->{rel} eq 'next') {
+	    $self->next_page($l->{href});
+	}
+    }
+    
     # return a ref to the data array
     return \@ao;
  }    
 
 =pod
 
-=encoding ISO-8859-1
-
 =head1 NAME
 
 NOLookup::Brreg::Entry - Map a Brreg json data structure element
@@ -224,22 +175,10 @@ data objects.
 
 Returns a ref. to an array of NOLookup::Brreg::Entry data objects.
 
-=head3 cur_page()/prev_page()/next_page()
-
-If more pages can be fetched, those methods give the URL to that page
-
-=head3 total_page_count()
-
-Count of total nuber of pages matching the search
-
-=head3 result_count()
-
-Count of results on this page
-
-=head3 total_result_count()
-
-Count of total results for the search
+=head3 next_page()
 
+If more pages (of 100 elements) can be fetched,
+this method gives the URL to that page.
 
 =head2 Accessor methods
 
@@ -247,24 +186,20 @@ Data elements are available through acessors in the NOLookup::Brreg::Entry objec
 This is the possible JSON data methods, which are the accessor
 methods that can be used to find the returned data elements.
 
-The accessor methods from @json_data_methods
+The accessor methods are:
 
   organisasjonsnummer 
   navn 
-  oppdateringsid
   registreringsdatoEnhetsregisteret 
-  stiftelsesdato
-  oppstartsdato
+  stiftelsesdato 
   sisteInnsendteAarsregnskap 
-* organisasjonsform
+  organisasjonsform
   overordnetEnhet
-  maalform
   registrertIStiftelsesregisteret
   registrertIFrivillighetsregisteret
   registrertIMvaregisteret
   registrertIForetaksregisteret
-  frivilligMvaRegistrertBeskrivelser
-
+* frivilligRegistrertIMvaregisteret
   underAvvikling
   konkurs
   underTvangsavviklingEllerTvangsopplosning
@@ -274,8 +209,7 @@ The accessor methods from @json_data_methods
 * naeringskode1 
 * naeringskode2
 * naeringskode3
-* _links
-* page
+* links 
   hjemmeside 
   antallAnsatte
 
@@ -289,35 +223,18 @@ Hash data must be accessed via their respective keys.
 
 The hashes are described below.
 
-=head3 organisasjonsform()
-
-The hash looks like follows:
-
-  "organisasjonsform": {
-    "kode": "AS",
-    "beskrivelse": "Aksjeselskap",
-    "_links": {
-      "self": {
-        "href": "https://data.brreg.no/enhetsregisteret/api/organisasjonsformer/AS"
-      }
-    }
-  },
-
-
 =head3 forretningsadresse() / postadresse()
 
 The hash looks like follows:
 
- "forretningsadresse": {
-    "land": "Norge",
-    "landkode": "NO",
-    "postnummer": "7030",
-    "poststed": "TRONDHEIM",
-    "adresse": [
-      "Abels gate 5"
-    ],
-    "kommune": "TRONDHEIM",
-    "kommunenummer": "5001"
+  'forretningsadresse' => {
+    'land' => 'Norge',
+    'kommune' => 'STAVANGER',
+    'postnummer' => '4035',
+    'poststed' => 'STAVANGER',
+    'kommunenummer' => '1103',
+    'landkode' => 'NO',
+    'adresse' => 'Forusbeen 50'
   },
 
 =head3 institusjonellSektorkode()
@@ -329,7 +246,7 @@ The hash looks like follows:
     'kode' => '1120'
   }
 
-=head3 naeringskode1/2/3()
+=head3 naeringskode1() / naeringskode2()
 
 The hash looks like follows:
 
@@ -338,24 +255,25 @@ The hash looks like follows:
     'kode' => '06.100'
   },
 
-=head3 frivilligMvaRegistrertBeskrivelser()
+=head3 frivilligRegistrertIMvaregisteret()
 
 The hash looks like follows:
 
-  'frivilligMvaRegistrertBeskrivelser' => [
+  'frivilligRegistrertIMvaregisteret' => [
     'Utleier av bygg eller anlegg'
   ],
 
 
-=head3 _links() 
+=head3 links() 
 
 The hash looks like follows:
 
- "_links": {
-    "self": {
-      "href": "https://data.brreg.no/enhetsregisteret/api/enheter/985821585"
-    }
-  }
+  'links' => [
+     {
+       'rel' => 'self',
+       'href' => 'http://data.brreg.no/enhetsregisteret/enhet/923609016'
+     }
+   ]
 
 
 =head1 SUPPORT
@@ -376,7 +294,7 @@ Trond Haugen, E<lt>(nospam)info(at)norid.noE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2017- Trond Haugen <(nospam)info(at)norid.no>.
+Copyright (c) 2016 Trond Haugen <(nospam)info(at)norid.no>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
